@@ -33,34 +33,38 @@ let is_installed =
 
 type config = (string * string) list
 
-let get_config = lazy (
-  let cmd = sprintf "%s --dump-config" Config.nbdkit in
-  let lines = external_command cmd in
-  List.map (String.split "=") lines
-)
-let config () = Lazy.force get_config
+let config =
+  let output =
+    lazy (
+      let cmd = sprintf "%s --dump-config" Config.nbdkit in
+      let lines = external_command cmd in
+      List.map (String.split "=") lines
+    ) in
+  fun () -> Lazy.force output
 
 type version = int * int * int
 
 let rex = PCRE.compile "^(\\d+)\\.(\\d+)\\.(\\d+)"
-let get_version = lazy (
-  let config = config () in
-  let version =
-    try List.assoc "version" config
-    with Not_found -> failwith "nbdkit: no version in --dump-config" in
-  if not (PCRE.matches rex version) then
-    error (f_"nbdkit: unexpected version in --dump-config: %s") version;
-  let major = int_of_string (PCRE.sub 1)
-  and minor = int_of_string (PCRE.sub 2)
-  and release = int_of_string (PCRE.sub 3) in
-  if verbose () then (
-    eprintf "info: nbdkit version:\n%!";
-    ignore (Sys.command (sprintf "%s --version >&2" Config.nbdkit));
-    eprintf "parsed version: %d.%d.%d\n%!" major minor release
-  );
-  (major, minor, release)
-)
-let version () = Lazy.force get_version
+let version =
+  let v =
+    lazy (
+      let config = config () in
+      let version =
+        try List.assoc "version" config
+        with Not_found -> failwith "nbdkit: no version in --dump-config" in
+      if not (PCRE.matches rex version) then
+        error (f_"nbdkit: unexpected version in --dump-config: %s") version;
+      let major = int_of_string (PCRE.sub 1)
+      and minor = int_of_string (PCRE.sub 2)
+      and release = int_of_string (PCRE.sub 3) in
+      if verbose () then (
+        eprintf "info: nbdkit version:\n%!";
+        ignore (Sys.command (sprintf "%s --version >&2" Config.nbdkit));
+        eprintf "parsed version: %d.%d.%d\n%!" major minor release
+      );
+      (major, minor, release)
+    ) in
+  fun () -> Lazy.force v
 
 let probe_server_parameter name =
   let list_options =
@@ -165,7 +169,7 @@ let run_unix socket cmd =
   add_arg "--unix"; add_arg socket;
   add_arg "--threads"; add_arg (string_of_int cmd.threads);
 
-  if have_selinux then (
+  if have_selinux () then (
     add_arg "--selinux-label";
     add_arg "system_u:object_r:svirt_socket_t:s0"
   );
@@ -214,7 +218,7 @@ let run_unix socket cmd =
 If the messages above are not sufficient to diagnose the problem then add the ‘virt-v2v -v -x’ options and examine the debugging output carefully.")
   );
 
-  if have_selinux then (
+  if have_selinux () then (
     (* Note that Unix domain sockets have both a file label and
      * a socket/process label.  Using --selinux-label above
      * only set the socket label, but we must also set the file
