@@ -23,13 +23,13 @@ val is_installed : unit -> bool
     rudimentary tests that it is working. *)
 
 type version = int * int * int
-(** Version of qemu-nbd: (major, minor, release). *)
+(** Version of qemu-nbd: [major, minor, release]. *)
 
 val version : unit -> version
 (** Get the installed version of qemu-nbd. *)
 
 type cmd
-(** A qemu-nbd command line.  Note this type is immutable. *)
+(** A qemu-nbd command line. *)
 
 val create : string -> cmd
 (** Create a new qemu-nbd command.
@@ -38,7 +38,10 @@ val create : string -> cmd
     disk image to serve. *)
 
 val set_snapshot : cmd -> bool -> unit
-(** Set the snapshot [-s] flag. *)
+(** If true, set the snapshot [-s] flag.
+
+    For safety, all input methods where [options.read_only] is true
+    must set this, to ensure the input is not modified. *)
 
 val set_format : cmd -> string option -> unit
 (** Set the format [--format] parameter. *)
