@@ -66,7 +66,8 @@ let error_if_disk_count_gt input_disks n =
 
 type on_exit_kill = Kill | KillAndWait
 
-let output_to_local_file ?(changeuid = fun f -> f ())
+let output_to_local_file ?name
+      ?(changeuid = fun f -> f ())
       ?(compressed = false)
       ?(create = true)
       ?(on_exit_kill = Kill)
@@ -99,7 +100,7 @@ let output_to_local_file ?(changeuid = fun f -> f ())
   let pid =
     match output_format with
     | "raw" ->
-       let cmd = Nbdkit.create "file" in
+       let cmd = Nbdkit.create ?name "file" in
        Nbdkit.add_arg cmd "file" filename;
        Nbdkit.add_arg cmd "cache" "none";
        if verbose () then Nbdkit.add_filter_if_available cmd "count";
@@ -202,7 +203,7 @@ let create_local_output_disks dir
     On_exit.unlink socket;
 
     (* Create the single nbdkit-file-plugin instance. *)
-    let cmd = Nbdkit.create "file" in
+    let cmd = Nbdkit.create ~name:"out" "file" in
     Nbdkit.add_arg cmd "dir" output_storage;
     Nbdkit.add_arg cmd "cache" "none";
     if verbose () then Nbdkit.add_filter_if_available cmd "count";
@@ -223,11 +224,13 @@ let create_local_output_disks dir
     (* Not the special case, use {!output_to_local_file} on each disk. *)
     List.mapi (
       fun i (size, outdisk) ->
-        let socket = sprintf "%s/out%d" dir i in
+        let sockname = sprintf "out%d" i in
+        let socket = sprintf "%s/%s" dir sockname in
         On_exit.unlink socket;
 
         (* Create the actual output disk. *)
-        output_to_local_file ~compressed ~create output_alloc output_format
+        output_to_local_file ~name:sockname ~compressed ~create
+          output_alloc output_format
           outdisk size socket;
 
         NBD_URI.Unix (socket, None)
