@@ -51,9 +51,7 @@ module Null = struct
     if options.output_storage <> None then
       error_option_cannot_be_used_in_output_mode "null" "-os"
 
-  let setup dir () source =
-    let disks = get_disks dir in
-
+  let setup dir () source input_disks =
     (* Check nbdkit is installed and has the required plugin. *)
     if not (Nbdkit.is_installed ()) then
       error (f_"nbdkit is not installed or not working.  \
@@ -78,16 +76,13 @@ module Null = struct
        *)
       On_exit.kill pid in
 
-    (* Use hard links to the same socket for the other disks. *)
-    List.iter (
-      fun (i, _) ->
-        if i > 0 then (
-          let output = sprintf "%s/out%d" dir i in
-          link socket output
-        )
-    ) disks
+    (* Same socket repeated for each input disk. *)
+    let uris =
+      List.make (List.length input_disks) (NBD_URI.Unix (socket, None)) in
 
-  let finalize dir () () source inspect target_meta =
+    (), uris
+
+  let finalize dir () () output_disks source inspect target_meta =
     () (* nothing to do *)
 
   let request_size = None
